function [lambdas, V, mu] = PCAShapes(Xa);

% Performs PCA of the covariance matrix of the aligned shape set Xa
% where each complex row is a shape
% Avoids V and mu computation if not requested in output

[s,N] = size(Xa);
n = 2*N;
Xr = zeros(s, n);
Xr(:,1:2:n) = real(Xa);
Xr(:,2:2:n) = imag(Xa);

mur = mean(Xr);
Xc = Xr - repmat(mur, s, 1);

if(s<n)
    covXtc = Xc * Xc' / s;
    %     covXtc = 0.5*(covXtc + covXtc'); not needed as in Procrustes
    [Vt,Dt] = eig(covXtc);
    lambdasR = diag(Dt);
    if nargout>1
        VR = Xc' * Vt;
        %     for ss=1:s
        %         VR(:,ss) = VR(:,ss) / norm(VR(:,ss));
        %     end   ... is done faster with:
        normVR = sqrt(sum(VR.*VR));
        VR = VR ./ repmat(normVR, n, 1);
    end
else 
    covXc = Xc' * Xc / s;
    [VR,D] = eig(covXc);
    lambdasR = diag(D);
end

minns = min(n,s);
skip = 1; % The smallest e-values are degenerate due to alignment
lambdas = lambdasR(end:-1:end-minns+1+skip)';


if nargout>1
    Vr = VR(:,end:-1:end-minns+1+skip);
    
    mu = mur(1:2:end) + j * mur(2:2:end);
    V = Vr(1:2:end,:) + j * Vr(2:2:end,:);
end
